import Taro, { useDidShow, useLaunch, useDidHide } from '@tarojs/taro'
import "taro-ui/dist/style/components/accordion.scss";
import "taro-ui/dist/style/components/icon.scss";
import './app.less'

export default function App(props: any) {
  useDidShow(()=>{
    console.log('进入小程序并登录')
    Taro.setStorageSync('EntryTime', Date.now()) // 记录进入小程序的时间
    Taro.login({
      success:function(res) {
        console.log('微信登录成功', res.code)

        Taro.request({
          method: 'POST',
          url: 'https://interapi.jm-kid.com/api/login',
          data: {
            CODE: res.code,
            channel: 'wusehua_mini',
          },
          success: function(sres) {
            console.log('静默授权登录成功', sres.data)

            if(sres.data.state === 200){
              Taro.setStorageSync('UserAvatar', sres.data.data.user.Avatar)
              Taro.setStorageSync('UserNickName', sres.data.data.user.NickName)
              Taro.setStorageSync('UserPhoneNumber', sres.data.data.user.Mobile)
              Taro.setStorageSync('UserInviteCode', sres.data.data.user.InviteCode)
              Taro.setStorageSync('UserToken', sres.data.token)
            }else{
              //注册key
              Taro.setStorageSync('LoginKey', sres.data.open_id)
            }
          }
        })
      }
    })
  })

  useDidHide(() => {
    const time = Taro.getStorageSync('EntryTime')
    if (time) {
      const duration = parseInt(((Date.now() - time) / 1000).toString())
      Taro.request({
        method: 'POST',
        url: 'https://interapi.jm-kid.com/api/user/online/duration',
        header: {
          authorization: `bearer ${Taro.getStorageSync('UserToken')}`
        },
        data: {
          timestamp: Date.now(),
          duration
        },
        success: (res: any) => {
          console.log('小程序离开：', res, duration)
        }
      })
    }
  })

  useLaunch(()=>{
    const updateManager = Taro.getUpdateManager()
    updateManager.onCheckForUpdate(function (res) {
    // 请求完新版本信息的回调
    // console.log(res.hasUpdate)
    })
    updateManager.onUpdateReady(function () {
      Taro.showModal({
        title: '更新提示',
        content: '新版本已经准备好，是否重启应用？',
        success: function (res) {
          if (res.confirm) {
            // 新的版本已经下载好，调用 applyUpdate 应用新版本并重启
            updateManager.applyUpdate()
          }
        }
      })
    })
    updateManager.onUpdateFailed(function () {
      // 新的版本下载失败
    })
  })

  return (
    props.children

  )
}
