import { View, Text, Image, ScrollView } from '@tarojs/components';
import { useEffect, useState } from 'react';
import Taro from '@tarojs/taro';
import './index.less'

export default function PopupHalfScreen({ visible, onClose, hideFilter, onFilter }) {

  //弹窗内容数据
  const [popUpContextList, setpopUpContextList] = useState<any[]>([])
  const [states, setStates] = useState<any[]>([])
  const [refer, setRefer] = useState<any[]>([])

  //管理关闭动画状态
  const [isAnimationOpen, setisAnimationOpen] = useState(false)

  //记录用户筛选状态
  const [filterForm, setFilterForm] = useState({
    filter: '',
    state: '',
    refer: '',
  })

  useEffect(() => {
    Taro.request({
      url: 'https://interapi.jm-kid.com/api/product/filter',
      method: 'POST',
      header: {
        authorization: 'bearer ' + Taro.getStorageSync('UserToken')
      },
      data: {
        timestamp: Date.now(),
      },
      success: (res) => {
        console.log('订阅筛选分类请求成功=>', res.data)
        const { data } = res
        setpopUpContextList(data.data)
        setStates(data.state)
        setRefer(data.refer)
      },
      fail: (err) => {
        console.log('订阅筛选分类请求失败=>', err)
      }
    })
  }, [])



  if (!visible) {
    return null;
  }

  const handleOverlayClick = (event: any) => {
    // 点击蒙层时关闭弹窗
    setisAnimationOpen(true)
    setTimeout(() =>{
      setisAnimationOpen(false)
      onClose();
    }, 500)
  };

  const handleFilterSelect = (val: string) => {
    setFilterForm({
      ...filterForm,
      filter: filterForm.filter === val ? '' : val
    })
  }

  const handleStateSelect = (val: string) => {
    setFilterForm({
      ...filterForm,
      state: filterForm.state === val ? '' : val
    })
  }

  const handleReferSelect = (val: string) => {
    setFilterForm({
      ...filterForm,
      refer: filterForm.refer === val ? '' : val
    })
  }

  const handleReset = () => {
    setFilterForm({
      filter: '',
      state: '',
      refer: '',
    })
    onFilter('reset')
    handleOverlayClick(null)
  }

  const handleCommit = () => {
    onFilter(filterForm)
    handleOverlayClick(null)
  }

  return (
    <>
      <View
        className='popup_overlay'
        onClick={handleOverlayClick}
      />
      <View
        className={`popup_half_screen ${hideFilter ? 'half' : ''}`}
        onClick={onClose}
        style={
          !isAnimationOpen ? {} : {
            bottom: '-100%',
            transition: 'bottom 0.5s ease',
          }
        }
      >
        <View className='popup_content' onClick={(e) => e.stopPropagation()}>
          {/* 弹窗内容 */}
          <View className='popop_content_header'>
            <Image
              className='popup_content_header_icon'
              src='https://oss.jm-kid.com/wx_5colorflower/foldUp.svg'
              onClick={handleOverlayClick}
            />
            <View className='popup_content_header_title'>筛选</View>
          </View>
          <ScrollView
            className='popup_content_body'
            scrollY
            scrollWithAnimation
          >
            {
              !hideFilter && popUpContextList.map((item: any, index: number) => (
                <View
                  className='popup_content_body_item'
                  key={index}
                >
                  <Text className='popup_content_body_item_title'>{item.title}</Text>
                  <View className='popup_content_body_item_group'>
                    {
                      item.category.map((subItem: any, subIndex: number) => (
                        <View
                          className='popup_content_body_item_group_bar'
                          key={subIndex}
                          onClick={()=>handleFilterSelect(subItem.id)}
                          style={
                            filterForm.filter === subItem.id ? {
                              backgroundColor: '#3BA366'
                            } : {}
                          }
                        >
                          <Text
                            className='popup_content_body_item_group_bar_title'
                            style={
                              filterForm.filter === subItem.id ? {
                                color: '#ffffff'
                              } : {}
                            }
                          >{subItem.title}</Text>
                        </View>
                      ))
                    }
                  </View>
                </View>
              ))
            }
            <View className='popup_content_body_item'>
              <Text className='popup_content_body_item_title'>状态</Text>
              <View className='popup_content_body_item_group'>
                {
                  states.map((item: any, index: number) => (
                    <View
                      className='popup_content_body_item_group_bar'
                      key={index}
                      onClick={()=>handleStateSelect(item.id)}
                      style={
                        filterForm.state === item.id ? {
                          backgroundColor: '#3BA366'
                        } : {}
                      }
                    >
                      <Text
                        className='popup_content_body_item_group_bar_title'
                        style={
                          filterForm.state === item.id ? {
                            color: '#ffffff'
                          } : {}
                        }
                      >{item.title}</Text>
                    </View>
                  ))
                }
              </View>
            </View>

            <View className='popup_content_body_item'>
              <Text className='popup_content_body_item_title'>来源</Text>
              <View className='popup_content_body_item_group'>
                {
                  refer.map((item: any, index: number) => (
                    <View
                      className='popup_content_body_item_group_bar'
                      key={index}
                      onClick={()=>handleReferSelect(item.id)}
                      style={
                        filterForm.refer === item.id ? {
                          backgroundColor: '#3BA366'
                        } : {}
                      }
                    >
                      <Text
                        className='popup_content_body_item_group_bar_title'
                        style={
                          filterForm.refer === item.id ? {
                            color: '#ffffff'
                          } : {}
                        }
                      >{item.title}</Text>
                    </View>
                  ))
                }
              </View>
            </View>
          </ScrollView>
          <View className='popup_content_footer'>
            <View
              className='popup_content_footer_btn'
              style={{background: '#3BA366'}}
              onClick={handleReset}
            >
              <Text
                className='popup_content_footer_btn_text'
                style={{color: '#fff'}}
              >重置</Text>
            </View>
            <View
              className='popup_content_footer_btn'
              style={{background: '#FCCA1E'}}
              onClick={handleCommit}
            >
              <Text
                className='popup_content_footer_btn_text'
                style={{color: '#000'}}
              >确定</Text>
            </View>
          </View>
        </View>
      </View>
    </>
  );
}
