import { useState } from 'react'
import Taro from '@tarojs/taro'
import { Input, View, Text } from '@tarojs/components'
import './index.less'
import GetPhoneNumber from '../getPhoneModal'
import UserExchangeSuccessModal from '../UserExchangeSuccessModal'

interface Props{
  isOpen: boolean,
  setIsOpen: (isOpen: boolean) => void
}

export default function UserExchangeModal({ isOpen, setIsOpen }: Props) {

  const [inputValue, setinputValue] = useState('')

  const [userScene, setuserScene] = useState<any>(null)

  //管理登录弹窗
  const [isGetUsePhone, setisGetUsePhone] = useState(false)

  //管理登录弹窗
  const [isLoginOpen, setisLoginOpen] = useState(false)

  // 兑换成功弹窗
  const [isUserExchangeSuccessModalOpen, setisUserExchangeSuccessModalOpen] = useState(false)

  // 兑换接口返回的state
  const [exchangeState, setExchangeState] = useState('')

  // 兑换成功的商品名称字符串
  const [prdtNames, setPrdtNames] = useState('')

  // 兑换成功的商品名称数组
  const [prdtList, setPrdtList] = useState([])

  //唤起扫码
  const handleScanCode = () => {
    Taro.scanCode({
      success: (res: any) => {
        const { path } = res
        if(!Taro.getStorageSync('UserToken')){
          setisLoginOpen(true)
          setuserScene(path ? path.slice(-8) : '')
        }else{
          Taro.request({
            url: 'https://interapi.jm-kid.com/api/product/exchange',
            method: 'POST',
            header: {
              authorization: `bearer ${Taro.getStorageSync('UserToken')}`
            },
            data: {
              timestamp: Date.now(),
              change_code: path ? path.slice(-8) : ''
            },
            success: (s_res: any) => {
              const { state, data } = s_res.data
              setExchangeState(state)
              // 有返回商品名称，则显示；否则只显示提示语
              if(data && data.Subscribed){
                const list = data.Subscribed
                setPrdtNames(list.map((e: any) => e.PrdtTitle).join('；'))
                setPrdtList(list)
              }
              setIsOpen(false)
              setisUserExchangeSuccessModalOpen(true)
            },
            fail: (err: any) => {
              console.log('兑换失败=>', err)
            }
          })
        }

      }
    })
  }

  const handleExchange = () => {
    // if(inputValue.length === 8){
      Taro.request({
        url: 'https://interapi.jm-kid.com/api/product/exchange',
        method: 'POST',
        header: {
          authorization: `bearer ${Taro.getStorageSync('UserToken')}`
        },
        data: {
          timestamp: Date.now(),
          change_code: inputValue
        },
        success: (res: any) => {
          const { state, data } = res.data
          setExchangeState(state)
          // 有返回商品名称，则显示；否则只显示提示语
          if(data && data.Subscribed){
            const list = data.Subscribed
            setPrdtNames(list.map((e: any) => e.PrdtTitle).join('；'))
            setPrdtList(list)
          }
          setIsOpen(false)
          setisUserExchangeSuccessModalOpen(true)
        },
        fail: (err: any) => {
          console.log('兑换失败=>', err)
        }
      })
    // }else{
    //   Taro.showToast({
    //     title: '兑换码格式错误',
    //     icon: 'none'
    //   })
    // }

  }

  return (
    <>
      {
        isOpen && (
        <View>
          <View
            className='exchange_mask'
            onClick={() => setIsOpen(false)}
          ></View>
          <View className='exchange_modal'>
            <View className='exchange_header'>
              <View className='exchange_title'>兑换码</View>
              <View
                className='exchange_close'
                onClick={() => setIsOpen(false)}
              ></View>
            </View>
            <View
              className='exchange_scan'
              onClick={handleScanCode}
            ></View>
            <Input
              className='exchange_input'
              placeholder='请输入兑换码兑换商品'
              value={inputValue}
              onInput={(e) => setinputValue(e.detail.value)}
            ></Input>
            <View
              className='exchange_exchange'
              onClick={handleExchange}
            >
              <Text className='exchange_exchange_text'>兑换</Text>
            </View>
          </View>

          <GetPhoneNumber
            onClose={setisGetUsePhone}
            scene={userScene}
            modalVisible={isLoginOpen}
            onModalClose={() => setisLoginOpen(false)}
          ></GetPhoneNumber>
        </View>
      )}

      <UserExchangeSuccessModal exchangeState={exchangeState} prdtList={prdtList} prdtNames={prdtNames} isOpen={isUserExchangeSuccessModalOpen} setIsOpen={setisUserExchangeSuccessModalOpen}></UserExchangeSuccessModal>
    </>
  )
}
