import { Button, View, Text } from '@tarojs/components'
import { useState } from 'react'
import Taro, { useLoad } from '@tarojs/taro'
import './index.less'
import UserExchangeSuccessModal from '../../components/UserExchangeSuccessModal'

export default function GetPhoneNumber({ onClose, scene = null, modalVisible, onModalClose}) {

  //管理关闭动画状态
  const [isAnimationOpen, setisAnimationOpen] = useState(false)

  // 兑换成功弹窗
  const [isUserExchangeSuccessModalOpen, setisUserExchangeSuccessModalOpen] = useState(false)

  // 兑换接口返回的state
  const [exchangeState, setExchangeState] = useState('')

  // 兑换成功的商品名称字符串
  const [prdtNames, setPrdtNames] = useState('')

  // 兑换成功的商品名称数组
  const [prdtList, setPrdtList] = useState([])

  useLoad((query)=> {
    console.log('通过分享拿到的邀请码是：',query.inviteCode)
    query.inviteCode && Taro.setStorageSync('othersInviteCode', query.inviteCode)
  })

  if(!modalVisible){
    return null
  }

  const handleOverlayClick = (event: any) => {
    // 点击蒙层时关闭弹窗
    setisAnimationOpen(true)
    setTimeout(() =>{
      setisAnimationOpen(false)
      // onClose()
      onModalClose()
    }, 0)
  };

  const handleGetUserPhone = (e: any) => {
    console.log('注册接口：',e.detail, Taro.getStorageSync('othersInviteCode'))

    const open_id = Taro.getStorageSync('LoginKey')
    if (open_id) {
      Taro.request({
        url: 'https://interapi.jm-kid.com/api/register',
        method: 'POST',
        data: {
          MCODE: e.detail.code,
          channel: 'wusehua_mini',
          open_id,
          invite_code: Taro.getStorageSync('othersInviteCode')
        },
        success: (res: any) => {
          console.log('用户注册信息=>',res)
          Taro.setStorageSync('UserAvatar', res.data.user.Avatar)
          Taro.setStorageSync('UserNickName', res.data.user.NickName)
          Taro.setStorageSync('UserPhoneNumber', res.data.user.Mobile)
          Taro.setStorageSync('UserInviteCode', res.data.user.InviteCode)
          Taro.setStorageSync('UserToken', res.data.token)
          Taro.removeStorageSync('othersInviteCode')

          if(scene){
            Taro.request({
              url: 'https://interapi.jm-kid.com/api/product/exchange',
              method: 'POST',
              header: {
                authorization: `bearer ${Taro.getStorageSync('UserToken')}`
              },
              data: {
                timestamp: Date.now(),
                change_code: scene
              },
              success: (s_res: any) => {
                const { state, data } = s_res.data
                setExchangeState(state)
                // 有返回商品名称，则显示；否则只显示提示语
                if(data && data.Subscribed){
                  const list = data.Subscribed
                  setPrdtNames(list.map((n: any) => n.PrdtTitle).join('；'))
                  setPrdtList(list)
                }
                setisUserExchangeSuccessModalOpen(true)
              },
              fail: (err: any) => {
                console.log('兑换失败=>', err)
              }
            })
          }

          //注册成功
          onClose(true)
          //关闭弹窗
          onModalClose()
        },
        fail: (err: any) => {
          console.log('用户注册失败=>',err)
        }
      })
    } else {
      // 如果没有openId，则先调登录
      Taro.login({
        success:function(res) {
          console.log('微信登录成功', res.code)

          Taro.request({
            method: 'POST',
            url: 'https://interapi.jm-kid.com/api/login',
            data: {
              CODE: res.code,
              channel: 'wusehua_mini',
            },
            success: function(sres) {
              console.log('静默授权登录成功', sres.data)

              if(sres.data.state === 200){
                Taro.setStorageSync('UserAvatar', sres.data.data.user.Avatar)
                Taro.setStorageSync('UserNickName', sres.data.data.user.NickName)
                Taro.setStorageSync('UserPhoneNumber', sres.data.data.user.Mobile)
                Taro.setStorageSync('UserInviteCode', sres.data.data.user.InviteCode)
                Taro.setStorageSync('UserToken', sres.data.token)

                //注册成功
                onClose(true)
                //关闭弹窗
                onModalClose()
              }else{
                //注册key
                Taro.setStorageSync('LoginKey', sres.data.open_id)
              }
            }
          })
        }
      })
    }
  }

  return (
    <>
      <View
        className='login_overlay'
        onClick={handleOverlayClick}
        style={
          !isAnimationOpen ? { opacity: 1, transition: 'opacity 1s ease-in-out' }
          : { opacity: 0 }
        }
      />

      <View className='light_border'>
        <View className='phone_modal'>

          <View className='phone_modal_logo'></View>
          {
            Taro.getStorageSync('LoginKey') ?
              <Button
                className='phone_modal_container'
                openType='getPhoneNumber'
                onGetPhoneNumber={handleGetUserPhone}
              >
                <View
                  className='phone_modal_title'
                >
                  手机号快捷登录
                </View>
              </Button> :
              <Button
                className='phone_modal_container'
                onClick={handleGetUserPhone}
              >
                <View
                  className='phone_modal_title'
                >
                  快捷登录
                </View>
              </Button>
          }

          <Text
            className='phone_modal_desc'
            onClick={handleOverlayClick}
          >暂不登录</Text>
        </View>
      </View>


      <UserExchangeSuccessModal exchangeState={exchangeState} prdtList={prdtList} prdtNames={prdtNames} isOpen={isUserExchangeSuccessModalOpen} setIsOpen={setisUserExchangeSuccessModalOpen}></UserExchangeSuccessModal>
    </>

  )
}
