import { View, Text, ScrollView, Image } from '@tarojs/components'
import Taro, { useLoad, useShareAppMessage, useShareTimeline } from '@tarojs/taro'
import React, { useEffect, useRef, useState } from 'react'
import './index.less'
import GoToStoreModal from '../../components/goToStoreModal'

interface DetailProps {
  Child: {
    PrdtCover: string,
    PrdtDescription: string,
    PrdtId: number,
    PrdtImages: string[],
    PrdtKeys: string[],
    PrdtRead: number,
    PrdtSubtitle: string,
    PrdtTitle: string,
  }[],
  IsFree: number,
  IsSubscribed: number,
  MallLink: string,
  Product: {
    PrdtCover: string,
    PrdtDescription: string,
    PrdtId: number,
    PrdtImages: string[],
    PrdtKeys: string[],
    PrdtRead: number,
    PrdtSubtitle: string,
    PrdtTitle: string,
  }
}

export default function CollectionDetail() {

  useShareAppMessage((res) => {
    if (res.from === 'button') {
      console.log(res.target);
    }
    return {
      title: '五色花',
      path: '/pages/Home/index'
    }
  })

  useShareTimeline(() => {
    return {
      title: '五色花',
      path: '/pages/Home/index'
    }
  })

  const [navigationBarHeight, setnavigationBarHeight] = useState(0)

  //产品详情
  const [productDetail, setproductDetail] = useState<DetailProps>()

  const [isToStoreOpen, setisToStoreOpen] = useState(false)

  //管理跳转页面路径
  const [prdtMallLink, setprdtMallLink] = useState('')

  useLoad((query) => {
    console.log('query=>', query.id)
    if(Taro.getStorageSync('UserToken')){
      Taro.request({
        url: 'https://interapi.jm-kid.com/api/product/detail',
        method: 'POST',
        header: {
          authorization: `bearer ${Taro.getStorageSync('UserToken')}`
        },
        data: {
          timestamp: Date.now(),
          prdt_id: query.id
        },
        success: (res) => {
          console.log('产品详情获取成功=>', res.data)
          setproductDetail(res.data.data)
        },
        fail: (err) => {
          console.log('产品详情获取失败=>', err)
        }
      })
    }else{
      Taro.request({
        url: 'https://interapi.jm-kid.com/api/product/detail',
        method: 'POST',
        data: {
          timestamp: Date.now(),
          prdt_id: query.id
        },
        success: (res) => {
          console.log('产品详情获取成功=>', res.data)
          setproductDetail(res.data.data)
        },
        fail: (err) => {
          console.log('产品详情获取失败=>', err)
        }
      })
    }

  })

  useEffect(() => {
    const sysInfo = Taro.getSystemInfoSync()
    const statusBarHeight = sysInfo.statusBarHeight
    if(statusBarHeight)
      setnavigationBarHeight(statusBarHeight + 12)
  }, [])

  const handleToSingleDetail = (id: string) => {
    if(productDetail?.IsSubscribed === 1 || productDetail?.IsFree === 1){
      //已订阅/免费，跳转详情页
      Taro.navigateTo({
        url: '/pages/SingleDetail/index?id=' + id
      })
    } else
    if(productDetail?.IsSubscribed === -1 || productDetail?.IsSubscribed === 2){
      //未订阅，跳转商城
      setprdtMallLink(productDetail.MallLink || '')
      setisToStoreOpen(true)
    }
    // Taro.navigateTo({
    //   url: '/pages/SingleDetail/index?id=' + id
    // })
  }

  return (
    <View className='collection_bg'>
      <View
        className='collection_back'
        style={{top: navigationBarHeight}}
        onClick={()=>Taro.navigateBack()}
      ></View>
      {
        productDetail && <View
          className='collection_cover'
          style={{backgroundImage: `url(${productDetail.Product.PrdtCover})`}}
        ></View>
      }

      <View
        className='collection_info_container'
      >
        <View className='collection_container'>
          <View className='collection_info'>
            <View className='collection_header'>
              <Text className='collection_title'>{productDetail?.Product.PrdtTitle}</Text>
              <Text className='collection_count'>{`共${productDetail?.Child.length}本`}</Text>
            </View>
            <View className='collection_desc'>{productDetail?.Product.PrdtDescription}</View>
          </View>
          <View
            className='collection_List'
          >
            {
              productDetail?.Child.map((item: any, index: number) => (
                <View
                  className='collection_item'
                  key={index}
                  onClick={() => handleToSingleDetail(item.PrdtId)}
                >
                  <Image
                    className='collection_item_cover'
                    src={item.PrdtCover}
                    lazyLoad
                  ></Image>
                  <View className='collection_item_info'>
                    <View className='collection_item_title'>{item.PrdtTitle}</View>
                    <View className='collection_item_subtitle'>{item.PrdtSubtitle}</View>

                    <View className='collection_item_label_container'>
                      {
                        item.PrdtKeys.map((keys_item: any, keys_index: number) => (
                          keys_index < 3 && <View
                            className='collection_item_label'
                            key={keys_index}
                          >
                            <View className='collection_item_label_text'>{keys_item}</View>
                          </View>
                        ))
                      }
                    </View>

                  </View>
                </View>
              ))
            }
          </View>
        </View>
      </View>

      <GoToStoreModal
        visible={isToStoreOpen}
        onClose={() => setisToStoreOpen(false)}
        type={0}
        mallLink={prdtMallLink}
        setmallLink={setprdtMallLink}
      ></GoToStoreModal>
    </View>
  )
}
