import { View, Image, Text } from '@tarojs/components'
import React, { useEffect, useState } from 'react'
import Taro, { useLoad } from '@tarojs/taro'
import './index.less'
import GetPhoneNumber from '../../components/getPhoneModal'
import GoToMemberModal from '../../components/goToMemberModal'

interface DetailProps {
  IsFree: boolean
  IsSubscribed: number
  MallLink: string
  Product: {
    PrdtCover: string
    PrdtId: number
    PrdtKeys: string[]
    PrdtSubtitle: string
    PrdtTitle: string
    PrdtDescription: string
  }
  Resources: {
    ResDuration: number
    ResId: number
    ResSeries: string
    ResSubtitle: string
    ResTitle: string
  }[]
}

export default function ListenDetail() {
  const [chooseIndex, setchooseIndex] = useState(0)

  const [detailData, setdetailData] = useState<DetailProps>({
    IsFree: false,
    IsSubscribed: 0,
    MallLink: '',
    Product: {
      PrdtCover: '',
      PrdtId: 0,
      PrdtKeys: [''],
      PrdtSubtitle: '',
      PrdtTitle: '',
      PrdtDescription: ''
    },
    Resources: [
      {
      ResDuration: 0,
      ResId: 0,
      ResSeries: '',
      ResSubtitle: '',
      ResTitle: '',
      }
    ],
  })

  //判断是否登录
  const [isGetUsePhone, setisGetUsePhone] = useState(Taro.getStorageSync('UserToken') ? true : false) //false

  //管理登录弹窗
  const [isLoginOpen, setisLoginOpen] = useState(false)

  const [isToStoreOpen, setisToStoreOpen] = useState(false)

  //记录prdtId
  const [queryId, setqueryId] = useState('')

  //会员开通状态
  const [memberInfo, setMemberInfo] = useState({})

  useLoad((query) => {
    setqueryId(query.prdtId)
    if(!isGetUsePhone){
      Taro.request({
        method: 'POST',
        url: 'https://interapi.jm-kid.com/api/audio/product/detail',
        data: {
          timestamp: Date.now(),
          prdt_id: query.prdtId
        },
        success: (res) => {
          console.log('获取熏听产品详情数据请求成功' ,res.data)
          setdetailData(res.data.data)
        }
      })
    }
  })

  const formatSecondsToTime = (seconds: number) => {
    // 将秒数转换为整数秒和毫秒
    const totalSeconds = Math.floor(seconds);

    // 分钟数
    const minutes = Math.floor(totalSeconds / 60);
    // 剩余秒数
    const remainingSeconds = totalSeconds % 60;

    // 补零操作
    const formattedMinutes = minutes.toString().padStart(2, '0');
    const formattedSeconds = remainingSeconds.toString().padStart(2, '0');

    return `${formattedMinutes}:${formattedSeconds}`;
  }

	// 消息推送授权
	const publicNotice = (callback) => {
    Taro.requestSubscribeMessage({
      tmplIds: ['F5kG9ryTuf3U09liOVIqqZDDEwNwiuWbLPPdoVpKPWI', 'cnMggWGwr0_cVw7Hf_fg3u74EDJdA0b4e56Ioy-Vr_Q'],
      success() {
        callback && callback()
      },
      fail() {
        callback && callback()
      },
    })
  }

  const handleDisplay = (item: DetailProps['Resources']) => {
    if (!Taro.getStorageSync('UserToken')) {
      publicNotice(() => setisLoginOpen(true))
    }else{
      console.log('IsSubscribed=>', memberInfo)

      // 埋点
      Taro.request({
        method: 'POST',
        url: 'https://interapi.jm-kid.com/api/embedpoint',
        header: {
          authorization: `bearer ${Taro.getStorageSync('UserToken')}`
        },
        data: {
          timestamp: Date.now(),
          action_code: '1004003',
          value: item.ResId
        }
      })

      if (!detailData.IsFree && memberInfo?.SubscribedState !== 1) { // 付费专辑 && 无会员
        //没有会员，跳转商城
        setisToStoreOpen(true)
      }else{
        Taro.navigateTo({
          url: '/pages/ListenDisplay/index?prdtId=' + detailData.Product.PrdtId + '&resId=' + item.ResId
        })
      }
    }
  }

  useEffect(()=> {
    if(Taro.getStorageSync('UserToken')){
      Taro.request({
        method: 'POST',
        url: 'https://interapi.jm-kid.com/api/embedpoint',
        header: {
          authorization: `bearer ${Taro.getStorageSync('UserToken')}`
        },
        data: {
          timestamp: Date.now(),
          action_code: chooseIndex ? '1004002' : '1004001',
          value: 0
        }
      })
    }
  }, [chooseIndex])

  useEffect(()=> {
    console.log('isGetUsePhone=>', isGetUsePhone)

    if(isGetUsePhone && queryId){
      Taro.request({
        method: 'POST',
        url: 'https://interapi.jm-kid.com/api/audio/product/detail',
        header: {
          'authorization': 'bearer ' + Taro.getStorageSync('UserToken')
        },
        data: {
          timestamp: Date.now(),
          prdt_id: queryId
        },
        success: (res) => {
          console.log('获取熏听产品详情数据请求成功' ,res.data)
          setdetailData(res.data.data)
        }
      })

      Taro.request({
        url: 'https://interapi.jm-kid.com/api/member/data',
        method: 'POST',
        header: {
          authorization: `bearer ${Taro.getStorageSync('UserToken')}`
        },
        data: {
          timestamp: Date.now(),
          member_type: 'audio'
        },
        success: (res: any) => {
          if(res.data.state === 200){
            setMemberInfo(res.data.data.main)
          }
        },
      })
    }
  }, [isGetUsePhone, queryId])

  return (
    <View className='listendetail_bg'>
      <View className='header'>
        <Image
          src={detailData.Product.PrdtCover}
          className='icon'
        ></Image>
        <View className='content'>
          <View className='title'>{detailData.Product.PrdtTitle}</View>
          <View className='subtitle'>{detailData.Product.PrdtDescription}</View>
          <View className='tags'>
            {
              detailData.Product.PrdtKeys.map((item, index) => (
                index < 2 &&<View
                  className='tag'
                  key={index}
                >
                  {item}
                </View>
              ))
            }
          </View>
        </View>
      </View>

      <View className='chooseBar'>
        <View
          className='item'
          onClick={() => {setchooseIndex(0)}}
        >
          <View
            className='title'
            style={chooseIndex === 0 ? {color: '#3ba366', fontWeight: '600', fontSize: '1rem'} : {}}
          >
            目录
          </View>
          {
            chooseIndex === 0 && <View className='line'></View>
          }
        </View>
        <View
          className='item'
          onClick={() => {setchooseIndex(1)}}
        >
          <View
            className='title'
            style={chooseIndex === 1 ? {color: '#3ba366', fontWeight: '600', fontSize: '1rem'} : {}}
          >
            介绍
          </View>
          {
            chooseIndex === 1 && <View className='line'></View>
          }
        </View>
      </View>

      {
        chooseIndex === 0 &&
          <View className='MusicList'>
            {
              detailData.Resources.map((item, index) => (
                <View
                  key={index}
                  className='item'
                  onClick={() => {handleDisplay(item)}}
                >
                  <View className='content'>
                    <View className='title'>{item.ResTitle}</View>
                    {/* <View className='subtitle'>{item.ResSubtitle}</View> */}
                    <View className='duration'>{formatSecondsToTime(item.ResDuration)}</View>
                  </View>
                  <View className='next'></View>
                </View>
              ))
            }
          </View>
      }

      {
        chooseIndex === 1 &&
          <View className='introduction'>
            <Text className='text'>
              {detailData.Product.PrdtDescription}
            </Text>
          </View>
      }

      <GetPhoneNumber
        onClose={setisGetUsePhone}
        modalVisible={isLoginOpen}
        onModalClose={() => setisLoginOpen(false)}
      ></GetPhoneNumber>

      <GoToMemberModal
        visible={isToStoreOpen}
        onClose={() => setisToStoreOpen(false)}
        memberInfo={memberInfo}
      ></GoToMemberModal>
    </View>
  )
}
