import { Input, View, Image, Text, ScrollView } from '@tarojs/components'
import Taro, { useLoad, useShareAppMessage, useShareTimeline } from '@tarojs/taro'
import React, { useState, useEffect } from 'react'
import './index.less'
import DefaultPage3 from '../../components/defaultPage3'


export default function SearchDetail() {

  useShareAppMessage((res) => {
    if (res.from === 'button') {
      console.log(res.target);
    }
    return {
      title: '五色花',
      path: '/pages/Home/index'
    }
  })

  useShareTimeline(() => {
    return {
      title: '五色花',
      path: '/pages/Home/index'
    }
  })

  //单本订阅列表
  const [userSubscribeSingleList, setuserSubscribeSingleList] = useState([])

  //套装订阅列表
  const [userSubscribeCollectionList, setuserSubscribeCollectionList] = useState([])

  //管理登录弹窗
  const [isGetUsePhone, setisGetUsePhone] = useState(false)

  const [timer, setTimer] = useState<any>(null);
  const [searchText, setSearchText] = useState<string>('');

  const [searchSingleResults, setSearchSingleResults] = useState<any[]>()
  const [searchCollectionResults, setsearchCollectionResults] = useState<any[]>()

  const [userSelect, setuserSelect] = useState(0)

  // 搜索逻辑
  const handleSearch = () => {
    if(searchText){
      //搜索单本结果
      Taro.request({
        method: 'POST',
        url: 'https://interapi.jm-kid.com/api/audio/search/product',
        data: {
          timestamp: Date.now(),
          title: searchText
        },
        success: (res: any) => {
          console.log('依据专辑标题搜索熏听专辑列表', res.data)
          setSearchSingleResults(res.data.data.products)
        }
      })
    } else {
      setSearchSingleResults([])
    }
  };

  useEffect(() => {
    clearTimeout(timer)
    setTimer(setTimeout(handleSearch, 300))
  }, [searchText])

  //跳转详情页
  const handleToCollectionDetail = (id: string) => {
    Taro.navigateTo({
      url: '/pages/CollectionDetail/index?id=' + id
    })
  }

  const handleToSingleDetail = (id: string) => {
    Taro.navigateTo({
      url: '/pages/ListenDetail/index?prdtId=' + id
    })
  }

  //点击取消按钮清楚搜索栏
  const handleClearResearch = () => {
    setSearchText('')
  }

  useLoad(() => {
    if(!Taro.getStorageSync('UserToken')){
      setisGetUsePhone(true)
    }
  })

  return (
    <View className='search_bg'>
      <View className='subscribe_header'>
        <View
          className='subscribe_header_searchContainer'
        >
        </View>
        <Input
          className='subscribe_header_input'
          placeholder='请输入搜索内容'
          value={searchText}
          onInput={(e) => setSearchText(e.detail.value)}
        ></Input>
        <View
          className='subscribe_header_dressing'
          // onClick={() => setisPopupOpen(!isPopupOpen)}
        >搜索</View>
        <Image
          className='subscribe_header_scanCodeBtn'
          src='https://oss.jm-kid.com/wx_5colorflower/searchIcon.png'
          // onClick={handleScanCode}
        ></Image>
        <Image
          src='https://oss.jm-kid.com/wx_5colorflower/error.png'
          className='subscribe_header_errorIcon'
          onClick={()=>handleClearResearch()}
        ></Image>
      </View>

      {/* 列表渲染 */}
      {
        searchSingleResults && searchSingleResults.length > 0 ?
          <ScrollView
            scrollY
            scrollWithAnimation
            className='subscribe_content'
            enableFlex
          >
            <View
              className='subscribe_container'
              style={userSelect === 0 ? { gridTemplateColumns: 'repeat(3, 1fr)' } : { gridTemplateColumns: 'repeat(2, 1fr)' }}
            >
              {
                searchSingleResults.map((item: any, index: number) => (
                  <View
                    className='subscribe_content_singleItem'
                    key={index}
                    onClick={() => handleToSingleDetail(item.PrdtId)}
                  >
                    {
                      item.isFree === 1 && (
                        <View className='relative_container'>
                          <View className='subscribe_content_singleItem_label'>
                            <Text className='subscribe_content_singleItem_label_text'>免费绘本</Text>
                          </View>
                        </View>
                      )
                    }

                    <Image
                      className='subscribe_content_singleItem_cover'
                      src={item.PrdtCover}
                      mode='aspectFill'
                      lazyLoad
                    ></Image>
                    <View className='subscribe_content_singleItem_title'>{item.PrdtTitle}</View>
                  </View>
                ))
            }
            </View>
          </ScrollView> :
          searchText && <DefaultPage3 tips='暂无这类专辑'></DefaultPage3>
      }
    </View>
  )
}
