import { Input, View, Image, Text, ScrollView } from '@tarojs/components'
import Taro, { useLoad, useShareAppMessage, useShareTimeline } from '@tarojs/taro'
import React, { useState, useEffect } from 'react'
import './index.less'
import DefaultPage3 from '../../components/defaultPage3'

export default function SearchDetail() {

  useShareAppMessage((res) => {
    if (res.from === 'button') {
      console.log(res.target);
    }
    return {
      title: '五色花',
      path: '/pages/Home/index'
    }
  })

  useShareTimeline(() => {
    return {
      title: '五色花',
      path: '/pages/Home/index'
    }
  })

  //单本订阅列表
  const [userSubscribeSingleList, setuserSubscribeSingleList] = useState([])

  //套装订阅列表
  const [userSubscribeCollectionList, setuserSubscribeCollectionList] = useState([])

  //管理登录弹窗
  const [isGetUsePhone, setisGetUsePhone] = useState(false)

  const [timer, setTimer] = useState<any>(null);
  const [searchText, setSearchText] = useState<string>('');

  const [searchSingleResults, setSearchSingleResults] = useState<any[]>()
  const [searchCollectionResults, setsearchCollectionResults] = useState<any[]>()

  const [userSelect, setuserSelect] = useState(0)

  // 搜索逻辑
  const handleSearch = () => {
    //搜索单本结果
    const searchSingle = searchText ? userSubscribeSingleList.filter(( item:any ) => item.PrdtTitle.includes(searchText)) : []
    console.log('searchSingle=>', searchSingle)
    setSearchSingleResults(searchSingle)

    //搜索套装结果
    const searchCollection = searchText ? userSubscribeCollectionList.filter(( item:any ) => item.PrdtTitle.includes(searchText)) : []
    console.log('searchCollection=>', searchCollection)
    setsearchCollectionResults(searchCollection)
  };

  useEffect(() => {
    clearTimeout(timer)
    setTimer(setTimeout(handleSearch, 300))
  }, [searchText])

  //跳转详情页
  const handleToCollectionDetail = (id: string) => {
    Taro.navigateTo({
      url: '/pages/CollectionDetail/index?id=' + id
    })
  }

  const handleToSingleDetail = (id: string) => {
    Taro.navigateTo({
      url: '/pages/SingleDetail/index?id=' + id
    })
  }

  //点击取消按钮清楚搜索栏
  const handleClearResearch = () => {
    setSearchText('')
  }

  useLoad(() => {
    if(!Taro.getStorageSync('UserToken')){
      setisGetUsePhone(true)
    }else{
      //查询用户订阅信息
      Taro.request({
        url: 'https://interapi.jm-kid.com/api/product/subscribed',
        method: 'POST',
        header: {
          authorization: 'bearer ' + Taro.getStorageSync('UserToken')
        },
        data: {
          access_token: Taro.getStorageSync('UserToken'),
          timestamp: Date.now(),
        },
        success: (res: any) => {
          console.log('用户订阅信息', res)

          //单本订阅列表
          let singleArr: any = []

          for(let item of res.data.data.FreeProducts){
            for(let sec_item of item.Child){

              if(!singleArr.some((arr_item : any) => arr_item.PrdtId === sec_item.PrdtId)){
                sec_item.isFree = 1
                singleArr.push(sec_item)
              }
            }
          }

          for(let item of res.data.data.SubscribedProducts){
            for(let sec_item of item.Child){

              if(!singleArr.some((arr_item : any) => arr_item.PrdtId === sec_item.PrdtId)){
                sec_item.isFree = 0
                singleArr.push(sec_item)
              }
            }
          }

          console.log('单本订阅列表', singleArr)
          setuserSubscribeSingleList(singleArr)

          //套装订阅列表
          let collectionArr: any = []
          for(let item of res.data.data.FreeProducts){
            if(!collectionArr.some((arr_item : any) => arr_item.PrdtId === item.PrdtId)){
              item.isFree = 1
              collectionArr.push(item)
            }
          }

          for(let item of res.data.data.SubscribedProducts){
            if(!collectionArr.some((arr_item : any) => arr_item.PrdtId === item.PrdtId)){
              item.isFree = 0
              collectionArr.push(item)
            }
          }

          console.log('套装订阅列表', collectionArr)
          setuserSubscribeCollectionList(collectionArr)
        }
      })
    }
  })

  return (
    <View className='search_bg'>
      <View className='subscribe_header'>
        <View
          className='subscribe_header_searchContainer'
        >
        </View>
        <Input
          className='subscribe_header_input'
          placeholder='请输入搜索内容'
          value={searchText}
          onInput={(e) => setSearchText(e.detail.value)}
        ></Input>
        <View
          className='subscribe_header_dressing'
          // onClick={() => setisPopupOpen(!isPopupOpen)}
        >搜索</View>
        <Image
          className='subscribe_header_scanCodeBtn'
          src='https://oss.jm-kid.com/wx_5colorflower/searchIcon.png'
          // onClick={handleScanCode}
        ></Image>
        <Image
          src='https://oss.jm-kid.com/wx_5colorflower/error.png'
          className='subscribe_header_errorIcon'
          onClick={()=>handleClearResearch()}
        ></Image>
      </View>

      <View className='subscribe_selection'>
        <View
          className='subscribe_selection_item'
          style={userSelect === 0 ? {color: '#3ba366', fontSize: '1rem', height: '1rem', lineHeight: '1rem'} : {color: 'rgba(0, 0, 0, .3)', fontSize: '.875rem', height: '.875rem', lineHeight: '.875rem'}}
          onClick={()=>{setuserSelect(0)}}
        >
          <Text className='subscribe_selection_item_text'>单本</Text>
        </View>
        <View
          className='subscribe_selection_item'
          style={userSelect === 1 ? {color: '#3ba366', fontSize: '1rem', height: '1rem', lineHeight: '1rem'} : {color: 'rgba(0, 0, 0, .3)', fontSize: '.875rem', height: '.875rem', lineHeight: '.875rem'}}
          onClick={()=>{setuserSelect(1)}}
        >
          <Text className='subscribe_selection_item_text'>套装</Text>
        </View>
      </View>

      {/* 列表渲染 */}
      {
        !isGetUsePhone && ((userSelect === 0 && searchSingleResults && searchSingleResults.length > 0) || (userSelect === 1 && searchCollectionResults && searchCollectionResults.length > 0)) ?
          <ScrollView
            scrollY
            scrollWithAnimation
            className='subscribe_content'
            enableFlex
          >
            <View
              className='subscribe_container'
              style={userSelect === 0 ? {gridTemplateColumns: 'repeat(3, 1fr)'} : {gridTemplateColumns: 'repeat(2, 1fr)'}}
            >
              {
                userSelect === 0 && searchSingleResults && searchSingleResults.length > 0 &&searchSingleResults.map((item: any, index: number) => (
                  <View
                    className='subscribe_content_singleItem'
                    key={index}
                    onClick={() => handleToSingleDetail(item.PrdtId)}
                  >
                    {
                      item.isFree === 1 && (
                        <View className='relative_container'>
                          <View className='subscribe_content_singleItem_label'>
                            <Text className='subscribe_content_singleItem_label_text'>免费绘本</Text>
                          </View>
                        </View>
                      )
                    }

                    <Image
                      className='subscribe_content_singleItem_cover'
                      src={item.PrdtCover}
                      mode='widthFix'
                      lazyLoad
                    ></Image>
                    <View className='subscribe_content_singleItem_title'>{item.PrdtTitle}</View>
                  </View>
                ))
              }

              {
                userSelect === 1 && searchCollectionResults && searchCollectionResults.length > 0 && searchCollectionResults.map((item: any, index: number) => (
                  <View
                    className='subscribe_content_collectionItem'
                    key={index}
                    onClick={() => handleToCollectionDetail(item.PrdtId)}
                  >
                    {
                      item.isFree === 1 && (
                        <View className='relative_container'>
                          <View className='subscribe_content_singleItem_label'>
                            <Text className='subscribe_content_singleItem_label_text'>免费绘本</Text>
                          </View>
                        </View>
                      )
                    }
                    <Image
                      className='subscribe_content_singleItem_cover'
                      src={item.PrdtCover}
                      lazyLoad
                    ></Image>
                    <View className='subscribe_content_singleItem_title'>{item.PrdtTitle}</View>
                    <View className='subscribe_content_collectionItem_count'>{`共${item.ChildCount}本`}</View>
                  </View>
                ))
              }
            </View>
          </ScrollView> :
          searchText && <DefaultPage3></DefaultPage3>
      }
    </View>
  )
}
