import { ScrollView, View, Image } from '@tarojs/components'
import React, { useEffect, useState } from 'react'

import Taro, { useLoad, useShareAppMessage, useShareTimeline } from '@tarojs/taro'
import './index.less'

const tabbarList = [
  // {
  //   tabIndex: 0,
  //   name: '互动绘本',
  //   cover: 'https://oss.jm-kid.com/wx_5colorflower/detailsTabbar1.png',
  //   url: '/pages/DisplayCocos/index',
  // },
  {
    tabIndex: 1,
    name: '视频绘本',
    cover: 'https://oss.jm-kid.com/wx_5colorflower/detailsTabbar2.png',
    url: '/pages/DisplayVideo/index',
  },
  {
    tabIndex: 2,
    name: '听绘本',
    cover: 'https://oss.jm-kid.com/wx_5colorflower/detailsTabbar4.png',
    url: '/pages/ListenBookDisplay/index',
  },
  // {
  //   tabIndex: 3,
  //   name: '录绘本',
  //   cover: 'https://oss.jm-kid.com/wx_5colorflower/detailsTabbar4.png',
  //   url: '/pages/DisplayVideo/index',
  // },
]

interface SingleDetailProps {
  PrdtCover: string,
  PrdtDescription: string,
  PrdtId: number,
  PrdtImages: string[],
  PrdtKeys: string[],
  PrdtRead: number,
  PrdtSubtitle: string,
  PrdtTitle: string,
}

export default function SingleDetail() {

  useShareAppMessage((res) => {
    if (res.from === 'button') {
      console.log(res.target);
    }
    return {
      title: '五色花',
      path: '/pages/Home/index'
    }
  })

  useShareTimeline(() => {
    return {
      title: '五色花',
      path: '/pages/Home/index'
    }
  })

  const [navigationBarHeight, setnavigationBarHeight] = useState(0)

  const [singleDetail, setsingleDetail] = useState<SingleDetailProps>()

  const [isVideo, setisVideo] = useState(false)
  const [isListenBook, setisListenBook] = useState(false)

  useLoad((query) => {
    console.log('query=>', query.id)
    if(Taro.getStorageSync('UserToken')){
      Taro.request({
        url: 'https://interapi.jm-kid.com/api/product/resource',
        method: 'POST',
        header: {
          authorization: `bearer ${Taro.getStorageSync('UserToken')}`
        },
        data: {
          timestamp: Date.now(),
          prdt_id: query.id
        },
        success: (res) => {
          console.log('产品资源获取成功=>', res.data)
          setsingleDetail(res.data.data.Product)
        },
        fail: (err) => {
          console.log('产品资源获取失败=>', err)
        }
      })
    }else{
      Taro.request({
        url: 'https://interapi.jm-kid.com/api/product/resource',
        method: 'POST',
        data: {
          timestamp: Date.now(),
          prdt_id: query.id
        },
        success: (res) => {
          console.log('产品资源获取成功=>', res.data)
          setsingleDetail(res.data.data.Product)
        },
        fail: (err) => {
          console.log('产品资源获取失败=>', err)
        }
      })
    }

    //判断是否需要显示伴读图标
    if(Taro.getStorageSync('UserToken')){
      Taro.request({
        url: 'https://interapi.jm-kid.com/api/product/resource',
        method: 'POST',
        header: {
          authorization: `bearer ${Taro.getStorageSync('UserToken')}`
        },
        data: {
          timestamp: Date.now(),
          prdt_id: query.id,
          res_type: '03',
        },
        success: (res) => {
          console.log('产品资源获取成功=>', res.data)

          res.data.data.StoryResource.length && setisListenBook(true)
          res.data.data.Resource.length && setisVideo(true)
        },
        fail: (err) => {
          console.log('产品资源获取失败=>', err)
        }
      })
    }else{
      Taro.request({
        url: 'https://interapi.jm-kid.com/api/product/resource',
        method: 'POST',
        data: {
          timestamp: Date.now(),
          prdt_id: query.id,
          res_type: '03',
        },
        success: (res) => {
          console.log('产品资源获取成功=>', res.data)

          res.data.data.StoryResource.length && setisListenBook(true)
          res.data.data.Resource.length && setisVideo(true)
        },
        fail: (err) => {
          console.log('产品资源获取失败=>', err)
        }
      })
    }
  })

  useEffect(() => {
    const sysInfo = Taro.getSystemInfoSync()
    const statusBarHeight = sysInfo.statusBarHeight
    if(statusBarHeight)
      setnavigationBarHeight(statusBarHeight + 12)

    console.log('navigationBarHeight=>', navigationBarHeight)
  }, [])

  const handleNavigateTo = (url: string) => {
    const isListen = url === '/pages/ListenBookDisplay/index'
    // 埋点
    Taro.request({
      method: 'POST',
      url: 'https://interapi.jm-kid.com/api/embedpoint',
      header: {
        authorization: `bearer ${Taro.getStorageSync('UserToken')}`
      },
      data: {
        timestamp: Date.now(),
        action_code: isListen ? '1003002' : '1003001',
        value: 0
      }
    })

    if(isListen){
      Taro.navigateTo({
        url: url + `?prdtId=${singleDetail?.PrdtId}`
      })
    }else{
      Taro.navigateTo({
        url: url + `?id=${singleDetail?.PrdtId}`
      })
    }
  }

  return (
    <>
      <ScrollView
        className='single_detail'
        scrollY
        scrollWithAnimation
      >
        <View
          className='single_back'
          style={{top: navigationBarHeight}}
          onClick={()=>{Taro.navigateBack()}}
        ></View>

        <View className='single_cover_container'>
          {
            singleDetail && <Image
              className='single_cover'
              src={singleDetail.PrdtCover}
            ></Image>
          }
        </View>

        {
          singleDetail && <Image
            className='single_bg'
            src={singleDetail.PrdtCover}
            mode='aspectFill'
          ></Image>
        }

        <View className='single_container'>
          <View className='single_title'>{singleDetail?.PrdtTitle}</View>
          <View className='single_label_container'>
            {
              singleDetail?.PrdtKeys.map((key_item: any, key_index: number) => (
                key_index < 4 && <View
                  className='single_label'
                  key={key_index}
                >
                  <View className='single_label_item'>{key_item}</View>
                </View>
              ))
            }
          </View>

          <View className='single_fixedTitle'>绘本介绍</View>
          <View className='single_intro'>{singleDetail?.PrdtDescription}</View>
          <View className='single_fixedTitle'>绘本配图</View>
          <View className='single_images_container'>
            {
              singleDetail && singleDetail.PrdtImages.length > 0 && singleDetail.PrdtImages.map((image_item: any, image_index: number) => (
                <Image
                  src={image_item}
                  key={image_index}
                  className='single_images_item'
                  lazyLoad
                ></Image>
              ))
            }
          </View>
        </View>

        {/* <View className='single_tabbar'>
          {
            tabbarList.map((item: any, index: number) => (
              <View
                className='single_tabbar_item'
                key={index}
                onClick={() => handleNavigateTo(item.url)}
              >
                <View
                  style={{backgroundImage: `url(${item.cover})`}}
                  className='single_tabbar_item_cover'
                ></View>
                <View className='single_tabbar_item_name'>{item.name}</View>
              </View>
            ))
          }
        </View> */}
      </ScrollView>

      <View className='single_tabbar'>
        {
          tabbarList.map((item: any, index: number) => (
            <View
              className='single_tabbar_item'
              key={index}
              onClick={() => handleNavigateTo(item.url)}
              style={( (item.tabIndex === 1 && !isVideo) || (item.tabIndex === 2 && !isListenBook) ) ? {display: 'none'} : {}}
            >
              <View
                style={{backgroundImage: `url(${item.cover})`}}
                className='single_tabbar_item_cover'
              ></View>
              <View className='single_tabbar_item_name'>{item.name}</View>
            </View>
          ))
        }
      </View>
    </>

  )
}
