import { ScrollView, View, Text, Input, Image } from '@tarojs/components'
import React, { useState, useEffect } from 'react'
import Taro, { useShareAppMessage, useShareTimeline } from '@tarojs/taro'
import DefaultPage2 from '../../../components/defaultPage2'
import PopupHalfScreen from '../../../components/Popup'
import UserExchangeSuccessModal from '../../../components/UserExchangeSuccessModal'
import './index.less'

interface subscribeProps {
  OrdDate: string,
  OrdRefer: number,
  PrdtCover: string,
  PrdtDeadline: string,
  PrdtId: number,
  PrdtSubtitle: string,
  PrdtTitle: string,
}

export default function UserSubscribe() {

  useShareAppMessage((res) => {
    if (res.from === 'button') {
      console.log(res.target);
    }
    return {
      title: '五色花',
      path: '/pages/Home/index'
    }
  })

  useShareTimeline(() => {
    return {
      title: '五色花',
      path: '/pages/Home/index'
    }
  })

  const [userSubuscribed, setuserSubuscribed] = useState<subscribeProps[]>()

  const [timer, setTimer] = useState<any>(null);
  //搜索框内容
  const [searchValue, setsearchValue] = useState('')

  const [isPopupOpen, setisPopupOpen] = useState(false)

  //记录用户筛选状态
  const [isFilter, setisFilter] = useState(null)

  // 兑换成功弹窗
  const [isUserExchangeSuccessModalOpen, setisUserExchangeSuccessModalOpen] = useState(false)

  // 兑换接口返回的state
  const [exchangeState, setExchangeState] = useState('')

  // 兑换成功的商品名称字符串
  const [prdtNames, setPrdtNames] = useState('')

  // 兑换成功的商品名称数组
  const [prdtList, setPrdtList] = useState([])

  //唤起扫码
  const handleScanCode = () => {
    console.log('唤起扫码')
    Taro.scanCode({
      success: (res: any) => {
        const { path } = res
        Taro.request({
          url: 'https://interapi.jm-kid.com/api/product/exchange',
          method: 'POST',
          header: {
            authorization: `bearer ${Taro.getStorageSync('UserToken')}`
          },
          data: {
            timestamp: Date.now(),
            change_code: path ? path.slice(-8) : ''
          },
          success: (s_res: any) => {
            const { state, data } = s_res.data
            setExchangeState(state)
            // 有返回商品名称，则显示；否则只显示提示语
            if(data && data.Subscribed){
              const list = data.Subscribed
              setPrdtNames(list.map((e: any) => e.PrdtTitle).join('；'))
              setPrdtList(list)
            }
            setisUserExchangeSuccessModalOpen(true)
            getList()
          },
          fail: (err: any) => {
            console.log('兑换失败=>', err)
          }
        })
      }
    })
  }

  const getList = () => {
    let data = {
      timestamp: Date.now(),
    }
    if (isFilter !== 'reset') data = {
      ...data,
      ...isFilter,
      title: searchValue
    }
    Taro.request({
      url: 'https://interapi.jm-kid.com/api/user/subscribed',
      method: 'POST',
      header: {
        authorization: `bearer ${Taro.getStorageSync('UserToken')}`,
      },
      data,
      success: (res: any) => {
        console.log('用户订阅查询成功=>', res.data)
        res.data.data.forEach((e: any) => {
          e.refer = e.OrdRefer === 1 ? '购买' : e.OrdRefer === 2 ? '兑换' : '赠送'
        })
        setuserSubuscribed(res.data.data)
      }
    })
  }

  useEffect(() => {
    getList()
  }, [isFilter])

  useEffect(() => {
    clearTimeout(timer)
    setTimer(setTimeout(getList, 300))
  }, [searchValue])


  //跳转详情页
  const handleToCollectionDetail = (item: any) => {
    const id = item.PrdtId
    Taro.navigateTo({
      // url: '/pages/CollectionDetail/index?id=' + id
      url: item.PrdtView === '03' ? `/pages/ListenRegion/index?index=${id === 5656 ? 334 : id}` : `/pages/CollectionDetail/index?id=${id}` // 熏厅和绘本跳不同的页面，并且熏听的音乐盒子专区是独立的，所以要固定id
    })
  }

  // 续费
  const toRenew = (item: any, e) => {
    e.stopPropagation()
    Taro.navigateToMiniProgram({
      appId: 'wxbd3d383851fea776',
      path: item.MallLink,
      success: (res) => {
        console.log('打开成功=>',res)
      },
      fail: (res) => {
        console.log('打开失败=>',res)
      }
    })
  }

  return (
    <View className='subscribe_bg'>
      <View className='subscribe_header'>
        <View
          className='subscribe_header_searchContainer'
        >
        </View>
        <Input
          className='subscribe_header_input'
          placeholder='请输入绘本套装名称'
          value={searchValue}
          confirmType='search'
          onInput={(e) => {
            setsearchValue(e.detail.value)
          }}
        ></Input>
        <View
          className='subscribe_header_dressing'
          onClick={() => setisPopupOpen(!isPopupOpen)}
        ></View>
        <Image
          className='subscribe_header_scanCodeBtn'
          src='https://oss.jm-kid.com/wx_5colorflower/scanCodeIcon.svg'
          onClick={handleScanCode}
        ></Image>
      </View>

      <PopupHalfScreen
        visible={isPopupOpen}
        onClose={() => setisPopupOpen(!isPopupOpen)}
        hideFilter='1'
        onFilter={setisFilter}
      ></PopupHalfScreen>

      <View>
        {
          userSubuscribed && userSubuscribed.length > 0 && userSubuscribed.map((item: any, index: number) => (
            <View
              className='subscribe_item'
              key={index}
              onClick={()=>handleToCollectionDetail(item)}
            >
              <View className='item_header'>
                <View className='item_header_addtime_icon'></View>
                <Text className='item_header_addtime_text'>最新订阅时间 {item.OrdDate} {item.refer}</Text>
                <View
                  className='item_header_icon'
                  style={
                    item.SubscribedState === 1 ? { backgroundColor: '#3BA366' } : { backgroundColor: '#FCCA1E' }
                  }
                >
                  <View
                    className='item_header_icon_text'
                    style={
                      item.SubscribedState === 1 ? { color: '#fff' } : { color: '#000' }
                    }
                  >
                    {
                      item.SubscribedState === -1 ? '已过期' : '生效中'
                    }
                  </View>
                </View>
              </View>
              <View className='item_content'>
                <View className={'content_container' + 1}>
                  <View className={'aspect_ratio_flex_container' + 1}>
                    <Image
                      className={'item_content_image' + 1}
                      src={item.PrdtCover}
                    ></Image>
                    {/* <View
                      className={'item_content_image' + 1}
                      style={{backgroundImage: `url(${item.PrdtCover})`}}
                    ></View> */}
                  </View>
                </View>

                <View
                  className='item_content_container'
                  style={
                    item.OrdRefer === 0 ? { width: 'calc(100% - 1rem - 7rem)', height: '7rem' } : { width: 'calc(100% - 1rem - 10.75rem)', height: '6.0469rem' }
                  }
                >
                  <View className='item_content_title'>{item.PrdtTitle}</View>
                  <View className='item_content_endtime'>到期时间：{item.PrdtDeadline.slice(0,10)}</View>
                  <View className='item_content_btn' onClick={(e) => toRenew(item, e)}>去续费 &gt;</View>
                </View>
                <View></View>
              </View>
            </View>
          ))
        }

        {
          userSubuscribed && userSubuscribed.length === 0 &&
          <DefaultPage2></DefaultPage2>
        }
      </View>

      <UserExchangeSuccessModal exchangeState={exchangeState} prdtList={prdtList} prdtNames={prdtNames} isOpen={isUserExchangeSuccessModalOpen} setIsOpen={setisUserExchangeSuccessModalOpen}></UserExchangeSuccessModal>
    </View>
  )
}
