import React, { useEffect, useState, useCallback } from 'react'
import Taro, { useDidHide, useDidShow, useLoad, useShareAppMessage, useShareTimeline } from '@tarojs/taro'
import { Image, View, Text } from '@tarojs/components'
import UserExchangeModal from '../../components/UserExchangeModal'

import './index.less'
import GetPhoneNumber from '../../components/getPhoneModal'

export default function UserHome() {
  useShareAppMessage((res) => {
    if (res.from === 'button') {
      console.log(res.target);
    }
    return {
      title: '五色花',
      path: '/pages/Home/index'
    }
  })

  useShareTimeline(() => {
    return {
      title: '五色花',
      path: '/pages/Home/index'
    }
  })

  const [operationList, setOperationList] = useState([
    {
      name: '我的订阅',
      icon: 'https://oss.jm-kid.com/wx_5colorflower/operate2.svg',
      pushUrl: '/pages/UserHome/UserSubscribe/index',
      des: 0,
    },
    {
      name: '熏听会员',
      icon: 'https://oss.jm-kid.com/wx_5colorflower/icons/operate5.svg',
      pushUrl: '/pages/Vip/index',
      des: '未开通',
    },
    {
      name: '兑换码',
      icon: 'https://oss.jm-kid.com/wx_5colorflower/operate1.svg',
      pushUrl: '',
    },
    {
      name: '商城',
      icon: 'https://oss.jm-kid.com/wx_5colorflower/icons/operate4.svg',
      pushUrl: '',
    },
    {
      name: '邀请好友',
      icon: 'https://oss.jm-kid.com/wx_5colorflower/icons/operate7.svg',
      pushUrl: '/pages/Share/index',
      des: '免费领绘本',
    },
    {
      name: '联系客服',
      icon: 'https://oss.jm-kid.com/wx_5colorflower/icons/operate8.svg',
      pushUrl: '/pages/Customer/index',
    },
    {
      name: '消息',
      icon: 'https://oss.jm-kid.com/wx_5colorflower/icons/operate6.svg',
      pushUrl: '/pages/UserHome/UserMessage/index',
      des: 0,
    },
  ])

  const [userAvator, setuserAvator] = useState('')

  const [userNickName, setuserNickName] = useState('')

  const [userName, setuserName] = useState('')

  const [isUserExchangeModalOpen, setisUserExchangeModalOpen] = useState(false)

  //管理登录弹窗
  const [isGetUsePhone, setisGetUsePhone] = useState(false)

  //管理登录弹窗
  const [isLoginOpen, setisLoginOpen] = useState(false)

  const [initialized, setInitialized] = useState(true);

  const handleGetUserProfile = () => {
    if(!Taro.getStorageSync('UserToken')){
      setisLoginOpen(true)
    }else{
      Taro.navigateTo({
        url: '/pages/UserHome/UserPersonalInfo/index'
      })
    }


    // Taro.getUserProfile({
    //   desc: '用于完善用户资料',
    //   success: (res: any) => {
    //     console.log(res.userInfo)

    //     setuserAvator(res.userInfo.avatarUrl)
    //     setuserName(res.userInfo.nickName)
    //   }
    // })
  }

  const handleUserInfo = useCallback(() => {
    setInitialized(false)
    console.log('更新用户信息', isGetUsePhone,Taro.getStorageSync('UserNickName'))
    setuserAvator(Taro.getStorageSync('UserAvatar') || '')
    setuserNickName(Taro.getStorageSync('UserNickName') || '')
    if(Taro.getStorageSync('UserToken')){
      Taro.request({
        url: 'https://interapi.jm-kid.com/api/info/num',
        method: 'POST',
        header: {
          authorization: `bearer ${Taro.getStorageSync('UserToken')}`
        },
        data: {
          timestamp: Date.now(),
        },
        success: (res: any) => {
          if(res.data.state === 200){
            // res.data.data
            const { data } = res.data
            const list = operationList
            const state = data.Member.SubscribedState // 会员状态
            list[0].des = data.Subscribed.Count
            list[1].des = state === -1 ? '已过期' : state === 1 ? '已开通' : '未开通' // -1 已过期 1 已开通 0 未开通
            list[6].des = data.Message.UnreadCount || ''
            setOperationList([...list])
          }
        },
      })
    } else {
      publicNotice(() => {
        const list = operationList
        list[0].des = ''
        list[1].des = ''
        list[6].des = ''
        setOperationList([...list])
        setisLoginOpen(true)
      })
    }
  }, [])

  useEffect(() => {
    initialized || handleUserInfo()
  }, [isGetUsePhone])

  //更新用户信息
  useDidShow(() => {
    handleUserInfo()
  })

  useDidHide(() => {
    if(Taro.getStorageSync('UserToken')){
      setuserAvator(Taro.getStorageSync('UserAvatar'))
      setuserNickName(Taro.getStorageSync('UserNickName'))
    } else {
      setisLoginOpen(false)
    }
    setisGetUsePhone(false)
  })

  // useLoad((query) => {
  //   if (decodeURIComponent(query.scene)) {
  //     let resid_reg = /id=(\d*)/;
  //     let bookid = resid_reg.exec(decodeURIComponent(query.scene))?.[1].trim()
  //     console.log('2useload', bookid)
  // }
  // })

	// 消息推送授权
	const publicNotice = (callback) => {
    Taro.requestSubscribeMessage({
      tmplIds: ['F5kG9ryTuf3U09liOVIqqZDDEwNwiuWbLPPdoVpKPWI', 'cnMggWGwr0_cVw7Hf_fg3u74EDJdA0b4e56Ioy-Vr_Q'],
      success() {
        callback && callback()
      },
      fail() {
        callback && callback()
      },
    })
  }

  const handlePush = (index: number,url: string) => {
    if (!Taro.getStorageSync('UserToken')) {
      setisLoginOpen(true)
    }else{
      if (index === 3) {
        // 商城
        handleNavigateToMiniProgram()
      } else if (index === 2) {
        // 兑换码
        setisUserExchangeModalOpen(true)
      } else if (index === 4) {
        // 联系客服
        publicNotice(() => {
          Taro.navigateTo({
            url: url,
          })
        })
      } else {
        Taro.navigateTo({
          url: url,
        })
      }
    }
  }

  const handleNavigateToMiniProgram = () => {
    Taro.navigateToMiniProgram({
      appId: 'wxbd3d383851fea776',
      path: 'pages/home/dashboard/index',
      success: (res) => {
        console.log('打开成功=>',res)
      },
      fail: (res) => {
        console.log('打开失败=>',res)
      }
    })
  }

  return (
    <View className='user_home_bg'>
      <View className='aspect_ratio_flex_container'>
        <View className='aspect_ratio_inner'>
          {/* 内容可以放在这里 */}
          <View className='user_home_header_bg'></View>
          <View className='use_home_header_info'>
            <Image className='user_home_header_info_icon'
              src={userAvator === '' ? 'https://oss.jm-kid.com/wx_5colorflower/header.svg' : userAvator}
              onClick={handleGetUserProfile}
            ></Image>
            <Text className='user_home_header_info_name'>{userNickName ? userNickName : '未登录'}</Text>
          </View>
        </View>
      </View>

      <View className='user_home_content'>
        {
          operationList.map((item: any, index: number) => (
            <View
              key={index}
              className='user_home_content_item'
              onClick={()=>handlePush(index ,item.pushUrl)}
            >
              <View className='user_home_content_item_inline'>
                <Image className='user_home_content_item_icon' mode='widthFix' src={item.icon}></Image>
                <Text className='user_home_content_item_name'>{item.name}</Text>
              </View>
              <View className='user_home_content_item_inline'>
                {item.des && <Text className='user_home_content_item_des'>{item.des}</Text>}
                <Image
                  className='user_home_content_item_btn'
                  src='https://oss.jm-kid.com/wx_5colorflower/next.svg'
                ></Image>
              </View>
            </View>
          ))
        }
      </View>

      <UserExchangeModal isOpen={isUserExchangeModalOpen} setIsOpen={setisUserExchangeModalOpen}></UserExchangeModal>

      <GetPhoneNumber
        onClose={setisGetUsePhone}
        modalVisible={isLoginOpen}
        onModalClose={() => setisLoginOpen(false)}
      ></GetPhoneNumber>
    </View>
  )
}
