import { View, Text, Image } from '@tarojs/components'
import Taro, { useLoad } from '@tarojs/taro'
import React, { useState } from 'react'
import './index.less'

interface RecordProps {
  CreateTime: string,
  PrdtDeadline: string,
  Title: string,
  SubscribedState?: number,
  MallLink: string
}

export default function Share() {
  const [userAvator, setuserAvator] = useState('')

  const [userNickName, setuserNickName] = useState('')

  // 会员信息
  const [info, setInfo] = useState<RecordProps>()

  // 开通记录
  const [records, setRecords] = useState<RecordProps[]>()

  const handleNavigateToMiniProgram = () => {
    Taro.navigateToMiniProgram({
      appId: 'wxbd3d383851fea776',
      path: info?.MallLink || '',
      success: (res) => {
        console.log('打开成功=>',res)
      },
      fail: (res) => {
        console.log('打开失败=>',res)
      }
    })
  }

  useLoad(()=> {
    setuserAvator(Taro.getStorageSync('UserAvatar'))
    setuserNickName(Taro.getStorageSync('UserNickName'))

    Taro.request({
      url: 'https://interapi.jm-kid.com/api/member/data',
      method: 'POST',
      header: {
        authorization: `bearer ${Taro.getStorageSync('UserToken')}`
      },
      data: {
        timestamp: Date.now(),
        member_type: 'audio'
      },
      success: (res: any) => {
        if(res.data.state === 200){
          const { list, main } = res.data.data
          setRecords(list)
          main && setInfo(main)
        }
      },
    })
  })

  return (
    <View className='vip'>
      <View className='vip_card'>
        <Image className='vip_avatar'
          src={userAvator === '' ? 'https://oss.jm-kid.com/wx_5colorflower/header.svg' : userAvator}
        ></Image>
        <View className='vip_info'>
          <View className='vip_name'>{userNickName}</View>
          <View className='vip_status'>{info?.SubscribedState ? info?.PrdtDeadline.split(' ')[0] + '日到期' : '未开通'}</View>
        </View>
        <View className='vip_open' onClick={handleNavigateToMiniProgram}>立即{info?.SubscribedState ? '续费' : '开通'}</View>
      </View>

      {
        records && records.length ?
        (<View className='vip_record'>
          <Text className='vip_title'>开通记录</Text>

            <View className='vip_list'>
              {
                records.map((item: any, index: number) => (
                  <View className='vip_list_item' key={index}>
                    <View className='vip_list_info'>
                      <Text>{item.Title}</Text>
                      <Text>1年</Text>
                    </View>
                    <View className='vip_list_date'>
                      <Text>开通时间：{item.CreateTime.split(' ')[0]}</Text>
                      <Text>到期时间：{item.PrdtDeadline.split(' ')[0]}</Text>
                    </View>
                  </View>
                ))
              }
          </View>
        </View>) :
        <View className='vip_none'>暂无开通记录~</View>
      }
    </View>
  )
}
